@@ -4,7 +4,7 @@
 pub type Error = std::io::Error;
 
 /// A result.
-pub type Result<T> = std::result::Result<T, Error>;
+pub type Result<T> = std::io::Result<T>;
 
 macro_rules! deref {
     ($name:ident::$field:tt => $target:ty) => (itemize! {
